#cython: boundscheck=False
import numpy as np
cimport numpy as np

def calculate_serial_cython(int maxiter, double complex[:] zs, double complex[:] cs):
    """Calculate output using Julia update rule."""
    cdef unsigned int i, n
    cdef double complex z, c
    cdef int[:] output = np.empty(len(zs), dtype=np.int32)
    for i in range(len(zs)):
        n = 0
        z = zs[i]
        c = cs[i]
        while (z.real*z.real + z.imag*z.imag) < 4.0 and n < maxiter:
            z = z * z + c
            n += 1
        output[i] = n
    return output
