import time
from functools import wraps
from cythonfn import calculate_serial_cython
x1, x2, y1, y2 = -1.8, 1.8, -1.8, 1.8
c_real, c_imag = 0.62772, -0.42193
def timefn(fn):
    @wraps(fn)
    def measure_time(*args, **kwargs):
        t1 = time.time()
        result = fn(*args, **kwargs)
        t2 = time.time()
        print(f"@timefn: {fn.__name__} took {t2 - t1} second")
        return result
    return measure_time
if "line_profiler" not in dir() and "profile" not in dir():
    def profile(func):
        return func
@profile
def prepare_inputs(width):
    """Create zs and cs."""
    dx = (x2 - x1)/width
    dy = (y1 - y2)/width
    x, y = [], []
    ycoord = y2
    while ycoord > y1:
        y.append(ycoord)
        ycoord += dy
    xcoord = x1
    while xcoord < x2:
        x.append(xcoord)
        xcoord += dx
    zs, cs = [], []
    for ycoord in y:
        for xcoord in x:
            zs.append(complex(xcoord, ycoord))
            cs.append(complex(c_real, c_imag))
    return zs, cs
@profile
def calculate_serial_purepython(maxiter, zs, cs):
    """Calculate output using Julia update rule."""
    output = [0] * len(zs)
    for i in range(len(zs)):
        n = 0
        z = zs[i]
        c = cs[i]
        while abs(z) < 2.0 and n < maxiter:
            z = z * z + c
            n += 1
        output[i] = n
    return output
if __name__ == "__main__":
    zs, cs = prepare_inputs(1000)
    output = calculate_serial_purepython(300, zs, cs)
    #import pickle
    #with open("zs_cs.pickle", "wb") as f:
    #    pickle.dump((zs, cs, output), f)
